"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = computeColumnWidths;

var _pipe = _interopRequireDefault(require("ramda/src/pipe"));

var _map = _interopRequireDefault(require("ramda/src/map"));

var _max = _interopRequireDefault(require("ramda/src/max"));

var _clamp = _interopRequireDefault(require("ramda/src/clamp"));

var _multiply = _interopRequireDefault(require("ramda/src/multiply"));

var _sum = _interopRequireDefault(require("ramda/src/sum"));

var _getColumnWeights = _interopRequireDefault(require("./getColumnWeights"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const minWidth = (0, _pipe.default)((0, _multiply.default)(5), (0, _max.default)(50));
const prefWidth = (0, _pipe.default)((0, _multiply.default)(8), (0, _clamp.default)(50, 150));
const totalMinWidths = (0, _pipe.default)((0, _map.default)(minWidth), _sum.default); // TODO: attempt const fn with https://ramdajs.com/docs/#useWith

function getResponsiveWidths(sumOfWeights, availableWidth, weights) {
  return (0, _map.default)(weight => weight / sumOfWeights * availableWidth)(weights);
}

function computeColumnWidths(display, availableWidth) {
  const columnWeights = (0, _getColumnWeights.default)(display.cells);
  const sumOfWeights = (0, _sum.default)(columnWeights);
  const sumOfMinWidths = totalMinWidths(columnWeights);
  const responsiveWidths = getResponsiveWidths(sumOfWeights, availableWidth, columnWeights);
  const sumOfResponsiveWidths = (0, _sum.default)(responsiveWidths);

  if (sumOfResponsiveWidths < sumOfMinWidths) {
    return (0, _map.default)(prefWidth, columnWeights);
  }

  return responsiveWidths;
}
//# sourceMappingURL=computeColumnWidths.js.map