"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = computeTNodeWeight;

var _pick = _interopRequireDefault(require("ramda/src/pick"));

var _pipe = _interopRequireDefault(require("ramda/src/pipe"));

var _sum = _interopRequireDefault(require("ramda/src/sum"));

var _map = _interopRequireDefault(require("ramda/src/map"));

var _values = _interopRequireDefault(require("ramda/src/values"));

var _multiply = _interopRequireDefault(require("ramda/src/multiply"));

var _transientRenderEngine = require("@native-html/transient-render-engine");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const fontWeightCoeffs = {
  '100': 0.8,
  '200': 0.85,
  '300': 0.9,
  '400': 1,
  '500': 1.1,
  '600': 1.2,
  '700': 1.3,
  '800': 1.4,
  '900': 1.5,
  bold: 1.3,
  normal: 1
};

function toNumber(value) {
  if (typeof value === 'number') {
    return value;
  }

  return 0;
}

const hspacingFields = ['borderLeftWidth', 'borderRightWidth', 'marginLeft', 'marginRight', 'paddingLeft', 'paddingRight'];
/**
 * 14ddp = 1wg
 */

const WEIGHT_U = 14;
const computeHzWeight = (0, _pipe.default)((0, _pick.default)(hspacingFields), _values.default, (0, _map.default)(toNumber), _sum.default, (0, _multiply.default)(1 / WEIGHT_U));

function computeTNodeWeight(tnode) {
  const hspaceWeight = computeHzWeight(tnode.styles.nativeBlockRet);

  if (tnode instanceof _transientRenderEngine.TText) {
    var _tnode$styles$nativeT, _tnode$styles$nativeT2, _fontWeightCoeffs$fon;

    const fontSize = (_tnode$styles$nativeT = tnode.styles.nativeTextFlow.fontSize) !== null && _tnode$styles$nativeT !== void 0 ? _tnode$styles$nativeT : WEIGHT_U;
    const fontWeight = (_tnode$styles$nativeT2 = tnode.styles.nativeTextFlow.fontWeight) !== null && _tnode$styles$nativeT2 !== void 0 ? _tnode$styles$nativeT2 : 'normal';
    const fontWeightCoeff = (_fontWeightCoeffs$fon = fontWeightCoeffs[fontWeight]) !== null && _fontWeightCoeffs$fon !== void 0 ? _fontWeightCoeffs$fon : 1;
    return (tnode.data.length + 1) * fontSize / WEIGHT_U * fontWeightCoeff + hspaceWeight;
  }

  return hspaceWeight + tnode.children.reduce((prev, curr) => computeTNodeWeight(curr) + prev, 0);
}
//# sourceMappingURL=computeTNodeWeight.js.map