"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createEmptyDisplay = createEmptyDisplay;
exports.default = fillTableDisplay;

var _computeTNodeWeight = _interopRequireDefault(require("./computeTNodeWeight"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function createEmptyDisplay() {
  return {
    offsetX: 0,
    occupiedCoordinates: [],
    maxY: 0,
    maxX: 0,
    cells: []
  };
}

function computeOffsetX(display, startX, startY) {
  return display.occupiedCoordinates.reduce((prev, coordinates) => {
    if (coordinates.x <= startX && coordinates.y === startY) {
      return prev + 1;
    }

    return 0;
  }, 0);
}

function fillTableDisplay(tnode, display) {
  if (tnode.tagName === 'tr') {
    display.maxY = tnode.nodeIndex;
    display.offsetX = 0;
  }

  if (tnode.tagName === 'th' || tnode.tagName === 'td') {
    const rowspan = Number(tnode.attributes.rowspan);
    const colspan = Number(tnode.attributes.colspan);
    const lenX = Number.isFinite(colspan) ? colspan : 1;
    const lenY = Number.isFinite(rowspan) ? rowspan : 1;
    const initialStartX = display.offsetX + tnode.nodeIndex;
    const startY = display.maxY;
    const startX = computeOffsetX(display, initialStartX, display.maxY) + initialStartX;
    const weight = (0, _computeTNodeWeight.default)(tnode);
    const cell = {
      lenX,
      lenY,
      x: startX,
      y: startY,
      tnode,
      weight
    };
    display.cells.push(cell);
    display.offsetX += lenX - 1;

    if (lenY > 1) {
      for (let y = startY + 1; y < lenY + startY; y++) {
        display.occupiedCoordinates.push({
          x: startX,
          y
        });
      }
    }

    display.maxX = Math.max(display.maxX, initialStartX);
  } else {
    tnode.children.forEach(child => fillTableDisplay(child, display));
  }
}
//# sourceMappingURL=fillTableDisplay.js.map