"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = useHtmlTableProps;

var _react = require("react");

var _computeColumnWidths = _interopRequireDefault(require("./helpers/computeColumnWidths"));

var _createRenderTree = _interopRequireDefault(require("./helpers/createRenderTree"));

var _fillTableDisplay = _interopRequireWildcard(require("./helpers/fillTableDisplay"));

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function useRenderTree({
  tnode,
  contentWidth
}) {
  return (0, _react.useMemo)(() => {
    const display = (0, _fillTableDisplay.createEmptyDisplay)();
    (0, _fillTableDisplay.default)(tnode, display);
    const columnWidths = (0, _computeColumnWidths.default)(display, contentWidth);
    return (0, _createRenderTree.default)(display, columnWidths);
  }, [tnode, contentWidth]);
}
/**
 * Customize the rendering logic of the table renderer via this hook.
 *
 * @param props - Props from custom renderer props.
 * @param options - Customize this hook behavior.
 *
 * @returns props for the {@link HTMLTable} component.
 *
 * @public
 */


function useHtmlTableProps({
  sharedProps,
  tnode,
  ...props
}, options = {}) {
  const {
    renderersProps: {
      table
    }
  } = sharedProps;
  const contentWidth = typeof options.overrideContentWidth === 'number' ? options.overrideContentWidth : sharedProps.contentWidth;
  const tree = useRenderTree({
    tnode,
    contentWidth
  });
  return {
    root: tree,
    config: table || {},
    contentWidth,
    sharedProps,
    tnode,
    ...props
  };
}
//# sourceMappingURL=useHtmlTableProps.js.map