import { useMemo } from 'react';
import computeColumnWidths from './helpers/computeColumnWidths';
import createRenderTree from './helpers/createRenderTree';
import fillTableDisplay, { createEmptyDisplay } from './helpers/fillTableDisplay';

function useRenderTree({
  tnode,
  contentWidth
}) {
  return useMemo(() => {
    const display = createEmptyDisplay();
    fillTableDisplay(tnode, display);
    const columnWidths = computeColumnWidths(display, contentWidth);
    return createRenderTree(display, columnWidths);
  }, [tnode, contentWidth]);
}
/**
 * Customize the rendering logic of the table renderer via this hook.
 *
 * @param props - Props from custom renderer props.
 * @param options - Customize this hook behavior.
 *
 * @returns props for the {@link HTMLTable} component.
 *
 * @public
 */


export default function useHtmlTableProps({
  sharedProps,
  tnode,
  ...props
}, options = {}) {
  const {
    renderersProps: {
      table
    }
  } = sharedProps;
  const contentWidth = typeof options.overrideContentWidth === 'number' ? options.overrideContentWidth : sharedProps.contentWidth;
  const tree = useRenderTree({
    tnode,
    contentWidth
  });
  return {
    root: tree,
    config: table || {},
    contentWidth,
    sharedProps,
    tnode,
    ...props
  };
}
//# sourceMappingURL=useHtmlTableProps.js.map